@@ -98,16 +98,15 @@
 #' library(ggrepel)
 #' # ggplot() methods for spectral objects set a default mapping for x and y.
 #' ggplot(sun.spct) + geom_line() +
-#'   stat_label_peaks(hjust = "left", span = 21, angle = 90) +
-#'   scale_color_identity()
+#'   stat_label_peaks(hjust = "left", span = 31, angle = 90, color = "red")
 #' ggplot(sun.spct) + geom_line() +
-#'   stat_label_valleys(hjust = "right", span = 21, angle = 90) +
-#'   scale_color_identity()
+#'   stat_label_valleys(hjust = "right", span = 21, angle = 90, color = "blue")
 #' ggplot(sun.spct) + geom_line() +
-#'   stat_peaks(span = 21, geom = "point", shape = 21, size = 3) +
-#'   stat_label_peaks(span = 21, geom = "text_repel", colour = "black",
-#'                    angle = 90, nudge_y = 0.12, label.fmt = "%3.0f nm") +
+#'   stat_peaks(span = 41, shape = 21, size = 3) +
+#'   stat_label_peaks(span = 41, geom = "label_repel", segment.colour = "red",
+#'                    nudge_y = 0.12, label.fmt = "%3.0f nm") +
 #'   scale_fill_identity() +
+#'   scale_color_identity() +
 #'   expand_limits(y = c(NA, 1))
 #' @export
 #' @family stats functions
@@ -187,11 +186,16 @@ StatLabelPeaks <-
                                                     photobiology::color(x, type = "CMF"),
                                                     "white")
                      )
+                     data[["BW.color"]] <- with(data,
+                                                 ifelse(is_peak,
+                                                        black_or_white(color),
+                                                        "black")
+                     )
                      data
                    },
                    default_aes = ggplot2::aes(label = ..x.label..,
                                               fill = ..color..,
-                                              color = ifelse(..color.. == "white", "black", ..color..),
+                                              color = ..BW.color..,
                                               xintercept = ..x..,
                                               yintercept = ..y..),
                    required_aes = c("x", "y")
@@ -261,11 +265,16 @@ StatLabelValleys <-
                                                     photobiology::color(x, type = "CMF"),
                                                     "white")
                      )
+                     data[["BW.color"]] <- with(data,
+                                                 ifelse(is_valley,
+                                                        black_or_white(color),
+                                                        "black")
+                     )
                      data
                    },
                    default_aes = ggplot2::aes(label = ..x.label..,
                                               fill = ..color..,
-                                              color = ifelse(..color.. == "white", "black", ..color..),
+                                              color = ..BW.color..,
                                               xintercept = ..x..,
                                               yintercept = ..y..),
                    required_aes = c("x", "y")
