@@ -1,7 +1,7 @@
 #' Label ranges under spectral curve.
 #'
 #' \code{stat_wb_label} computes computes the center of a waveband. Sets
-#' suitable default aestheics for "rect", "hline", "vline", "text" and "label"
+#' suitable default aesthetics for "text" and "label"
 #' geoms displaying "boundaries" and "names" of wavebands.
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
@@ -70,19 +70,26 @@
 #' # ggplot() methods for spectral objects set a default mapping for x and y.
 #' ggplot(sun.spct) +
 #'   geom_line() +
-#'   stat_wb_label(w.band = VIS(), geom = "rect", ymin = -0.04, ymax = 0,
+#'   stat_wb_box(w.band = VIS(), ymin = -0.04, ymax = 0,
 #'   color = "black", fill = "white") +
-#'   stat_wb_label(w.band = VIS(), y = -0.02)
+#'   stat_wb_label(w.band = VIS(), ypos.fixed = -0.02, color = "black")
+#'
+#' ggplot(sun.spct) +
+#'   geom_line() +
+#'   stat_wb_hbar(w.band = PAR(), ypos.fixed = 0, size = 1) +
+#'   stat_wb_label(aes(color = ..wb.color..),
+#'                 w.band = PAR(), ypos.fixed = +0.025) +
+#'   scale_color_identity()
 #'
 #' @export
 #' @family stats functions
 #'
 stat_wb_label <- function(mapping = NULL, data = NULL, geom = "text",
-                       w.band = NULL,
-                       label.fmt = "%s",
-                       ypos.fixed = 0,
-                       position = "identity", na.rm = FALSE, show.legend = NA,
-                       inherit.aes = TRUE, ...) {
+                          w.band = NULL,
+                          label.fmt = "%s",
+                          ypos.fixed = 0,
+                          position = "identity", na.rm = FALSE, show.legend = NA,
+                          inherit.aes = TRUE, ...) {
   ggplot2::layer(
     stat = StatWbLabel, data = data, mapping = mapping, geom = geom,
     position = position, show.legend = show.legend, inherit.aes = inherit.aes,
@@ -127,7 +134,8 @@ StatWbLabel <-
                                                     xmin = min(wb),
                                                     xmax = max(wb),
                                                     wb.color = color(wb),
-                                                    wb.name = labels(wb)$label)
+                                                    wb.name = labels(wb)$label,
+                                                    BW.color = black_or_white(color(wb)))
                                          )
                      }
                      if (is.null(ypos.fixed)) {
@@ -143,6 +151,7 @@ StatWbLabel <-
                                               x = ..x..,
                                               xmin = ..xmin..,
                                               xmax = ..xmax..,
-                                              fill = ..wb.color..),
+                                              fill = ..wb.color..,
+                                              color = ..BW.color..),
                    required_aes = c("x")
   )
