@@ -24,14 +24,37 @@
 #'   stripped before the computation proceeds.
 #' @param type character one of "CMF" (color matching function) or "CC"
 #'   (color coordinates).
-#' @param w.band photobiology::waveband object or a list of such objects or NULL.
+#' @param w.band waveband object or a list of such objects or NULL.
 #' @param length.out The number of steps to use to simulate a continuous
 #'   range of colours when w.band == NULL.
 #'
+#' @return generic_spect object with new \code{x} values plus other computed
+#'   variables described below.
+#'
 #' @section Computed variables:
 #' \describe{
-#'   \item{color}{color corresponding to x-value giving wavelength in
-#'   nanometres.}
+#'    \item{x}{(w.low + wl.high) / 2}
+#'    \item{wl.low}{boundary of waveband}
+#'    \item{wl.high}{boundary of waveband}
+#'    \item{wl.color}{color corresponding to wavelength}
+#'    \item{wb.color}{color corresponding to waveband}
+#'    \item{wb.name}{label of w.band}
+#' }
+#'
+#' @section Default aesthetics:
+#' Set by the statistic and available to geoms.
+#' \describe{
+#'   \item{x}{..x..}
+#'   \item{label}{as.character(..wb.f..)}
+#'   \item{xmin}{..wl.low..}
+#'   \item{xmax}{..wl.high..}
+#'   \item{fill}{..wb.color..}
+#' }
+#'
+#' @section Required aesthetics:
+#' Required by the statistic and need to be set with \code{aes()}.
+#' \describe{
+#'   \item{x}{numeric, wavelength in nanometres}
 #' }
 #'
 #' @seealso \code{\link[photobiology]{color}}, which is used internally.
@@ -77,7 +100,7 @@ StatColorGuide <-
                                             type,
                                             w.band,
                                             length.out) {
-                     if (is.null(w.band)) {
+                     if (length(w.band) == 0) {
                        w.band <- split_bands(range(data$x), length.out = length.out)
                      } else {
                        w.band <- trim_waveband(w.band = w.band, range = data$x, trim = TRUE)
