@@ -46,18 +46,29 @@ plot(sun.spct, unit.out = "photon")
 
 ## ------------------------------------------------------------------------
 plot(sun.spct, 
-     annotations = c("segments", "labels", "summaries", "color.guide"))
+     annotations = c("=", "segments", "labels", "summaries", "color.guide", "peaks"))
 
 ## ------------------------------------------------------------------------
 plot(sun.spct, 
-     annotations = NULL)
+     annotations = c("+", "segments"))
 
 ## ------------------------------------------------------------------------
-plot(sun.spct, annotations = c("segments", "labels", "color.guide"))
+plot(sun.spct, annotations = c("-", "summaries", "peaks"))
 
 ## ------------------------------------------------------------------------
-plot(sun.spct, 
-     annotations = c("segments", "labels", "color.guide"), 
+plot(sun.spct, annotations = c("+", "valleys"), span = 41)
+
+## ------------------------------------------------------------------------
+plot(sun.spct, annotations = c("+", "peak.labels", "valley.labels"), span = 41)
+
+## ------------------------------------------------------------------------
+plot(sun.spct, annotations = "")
+
+## ------------------------------------------------------------------------
+plot(sun.spct, annotations = "reserve.space")
+
+## ------------------------------------------------------------------------
+plot(sun.spct, annotations = c("=", "segments", "labels", "color.guide"), 
      text.size = 3.5)
 
 ## ------------------------------------------------------------------------
@@ -85,39 +96,39 @@ plot(sun.spct, w.band = PAR(), range = PAR())
 plot(sun.spct, w.band = VIS_bands(), range = VIS())
 
 ## ------------------------------------------------------------------------
+getTimeUnit(sun.daily.spct)
 plot(sun.daily.spct)
 
 ## ------------------------------------------------------------------------
 plot(two_suns.spct, label.qty = "mean") + facet_wrap(~spct.idx)
 
 ## ------------------------------------------------------------------------
-plot(two_suns.spct) + aes(linetype = spct.idx)
+plot(two_suns.spct, annotations = c("-", "summaries")) + 
+  aes(linetype = spct.idx)
+
+## ------------------------------------------------------------------------
+plot(rbindspct(list(sun = sun.spct, filtered = yellow_gel.spct * sun.spct)),
+     annotations = c("-", "summaries")) + 
+  aes(linetype = spct.idx)
+
+## ------------------------------------------------------------------------
+plot(yellow_gel.spct, annotations = c("-", "peaks"))
+
+## ------------------------------------------------------------------------
+plot(yellow_gel.spct, pc.out = TRUE, annotations = c("-", "peaks"))
+
+## ------------------------------------------------------------------------
+plot(yellow_gel.spct, plot.qty = "absorbance", annotations = c("-", "peaks"))
+
+## ------------------------------------------------------------------------
+yellow_gel.spct$Rfr <- 1 - max(yellow_gel.spct$Tfr)
+plot(yellow_gel.spct, plot.qty = "absorptance", annotations = c("-", "peaks"))
 
 ## ------------------------------------------------------------------------
 plot(sun.spct) + geom_spct(fill = color(sun.spct)) + 
   geom_spct(data = yellow_gel.spct * sun.spct, color = "black", 
             fill = color(yellow_gel.spct * sun.spct))
 
-## ------------------------------------------------------------------------
-plot(yellow_gel.spct)
-
-## ------------------------------------------------------------------------
-plot(yellow_gel.spct, pc.out = TRUE)
-
-## ------------------------------------------------------------------------
-plot(yellow_gel.spct, plot.qty = "absorbance")
-
-## ------------------------------------------------------------------------
-yellow_gel.spct$Rfr <- 1 - max(yellow_gel.spct$Tfr)
-plot(yellow_gel.spct, plot.qty = "absorptance")
-
-## ------------------------------------------------------------------------
-plot(sun.spct) + geom_spct(fill = color(sun.spct)) + 
-  geom_spct(data = yellow_gel.spct * sun.spct, color = "black", 
-            fill = color(yellow_gel.spct * sun.spct)) +
-  stat_peaks(data = yellow_gel.spct * sun.spct, color = "yellow", 
-             ignore_threshold = 0.1, span = 21)
-
 ## ------------------------------------------------------------------------
 two_suns.mspct <- source_mspct(list(sun1 = sun.spct, sun2 = sun.spct * 2))
 
@@ -129,9 +140,26 @@ plot(rbindspct(two_suns.mspct)) + facet_wrap(~spct.idx, ncol = 1)
 
 ## ------------------------------------------------------------------------
 plot(rbindspct(two_suns.mspct), 
-     annotations = c("color.guide", "labels", "boxes", "peaks")) + 
+     annotations = c("-", "summaries")) + 
   aes(linetype = spct.idx)
 
+## ------------------------------------------------------------------------
+plot(rbindspct(two_suns.mspct), 
+     annotations = c("-", "summaries"), span = 301) + 
+  aes(color = ifelse(spct.idx == "sun1", "darkgreen", "darkred"))
+
+## ------------------------------------------------------------------------
+plot(rbindspct(two_suns.mspct), annotations = "") + 
+  aes(linetype = spct.idx) +
+  wl_guide(ymax = -0.05)
+
+## ------------------------------------------------------------------------
+plot(sun.spct, annotations = c("-", "peaks")) +
+  stat_peaks(span = NULL, color = "red") +
+  stat_peaks(span = NULL, geom = "text", 
+             label.fmt = "max at %3.1f nm",
+             vjust = -0.4, color = "red")
+
 ## ------------------------------------------------------------------------
 ggplot(rbindspct(two_suns.mspct)) + 
   aes(linetype = spct.idx) +
@@ -142,8 +170,8 @@ ggplot(rbindspct(two_suns.mspct)) +
 plot(VIS())
 
 ## ------------------------------------------------------------------------
-plot(CIE(), range = CIE())
+plot(CIE(), range = CIE(), annotations = c("-", "color.guide"))
 
 ## ------------------------------------------------------------------------
-plot(DNA_N(), range = c(270, 420))
+plot(DNA_N(), range = c(270, 420), annotations = c("-", "color.guide"))
 
